@@ -32,11 +32,11 @@
 #'
 #'@examples
 #'\dontrun{
-#'download_core_nlp()
-#'download_core_nlp(type="spanish")
+#'cnlp_download_corenlp()
+#'cnlp_download_corenlp(type="spanish")
 #'}
 #' @export
-download_core_nlp <- function(
+cnlp_download_corenlp <- function(
     type = c("default", "base", "en", "fr", "de", "es"),
     output_loc, url = NULL, url_core = TRUE, force = FALSE) {
 
@@ -62,22 +62,24 @@ download_core_nlp <- function(
   # if url is given, simply download the specified files as required
   if (!is.null(url)) {
     if (url_core) {
-      fp <- .check_file_exists(file.path(output_loc,
-                                         coreFile),
-                               force = force)
-      f <- RCurl::CFILE(fp, mode="wb")
-      ret <- RCurl::curlPerform(url = url, writedata = f@ref,
-                                noprogress=FALSE)
-      RCurl::close(f)
-      if (ret != 0) stop("Download error!")
+      if (!dir.exists(file.path(output_loc, coreFile))) {
+        fp <- check_file_exists(file.path(output_loc,
+                                           paste0(coreFile, ".zip")),
+                                 force = force)
+        f <- RCurl::CFILE(fp, mode="wb")
+        ret <- RCurl::curlPerform(url = url, writedata = f@ref,
+                                  noprogress=FALSE)
+        RCurl::close(f)
+        if (ret != 0) stop("Download error!")
 
-      utils::unzip(file.path(output_loc, paste0(coreFile, ".zip")),
-                   exdir = output_loc)
-      file.remove(file.path(output_loc, paste0(coreFile, ".zip")))
-      return(0L)
+        utils::unzip(file.path(output_loc, paste0(coreFile, ".zip")),
+                     exdir = output_loc)
+        file.remove(file.path(output_loc, paste0(coreFile, ".zip")))
+        return(0L)
+      }
     } else {
       fname <- basename(url)
-      fp <- .check_file_exists(file.path(output_loc, coreFile, fname),
+      fp <- check_file_exists(file.path(output_loc, coreFile, fname),
                                force = force)
       f <- RCurl::CFILE(fp, mode="wb")
       ret <- RCurl::curlPerform(url = url, writedata = f@ref,
@@ -90,18 +92,20 @@ download_core_nlp <- function(
   type <- match.arg(type)
 
   if (type %in% c("default", "base")) {
-    fp <- .check_file_exists(file.path(output_loc, coreFile),
-                             force = force)
-    f <- RCurl::CFILE(fp, mode="wb")
-    ret <- RCurl::curlPerform(url = paste0(baseURL, coreFile, ".zip"),
-                              writedata = f@ref, noprogress=FALSE)
-    RCurl::close(f)
-    if (ret != 0) stop("Download error!")
+    if (!dir.exists(file.path(output_loc, coreFile))) {
+      fp <- check_file_exists(file.path(output_loc, paste0(coreFile, ".zip")),
+                               force = force)
+      f <- RCurl::CFILE(fp, mode="wb")
+      ret <- RCurl::curlPerform(url = paste0(baseURL, coreFile, ".zip"),
+                                writedata = f@ref, noprogress=FALSE)
+      RCurl::close(f)
+      if (ret != 0) stop("Download error!")
 
-    utils::unzip(file.path(output_loc, paste0(coreFile, ".zip")),
-                 exdir = output_loc)
-    file.remove(file.path(output_loc, paste0(coreFile, ".zip")))
-    ret <- 0L
+      utils::unzip(file.path(output_loc, paste0(coreFile, ".zip")),
+                   exdir = output_loc)
+      file.remove(file.path(output_loc, paste0(coreFile, ".zip")))
+      ret <- 0L
+    }
   }
 
   if (!file.exists(file.path(output_loc)))
@@ -109,7 +113,7 @@ download_core_nlp <- function(
          "Set type='base'.")
 
   if (type %in% c("default", "en")) {
-    fp <- .check_file_exists(file.path(output_loc, coreFile,
+    fp <- check_file_exists(file.path(output_loc, coreFile,
              "/stanford-english-corenlp-2016-10-31-models.jar"),
              force = force)
     f <- RCurl::CFILE(fp, mode="wb")
@@ -120,7 +124,7 @@ download_core_nlp <- function(
   }
 
   if (type %in% c("fr")) {
-    fp <- .check_file_exists(file.path(output_loc, coreFile,
+    fp <- check_file_exists(file.path(output_loc, coreFile,
              "/stanford-french-corenlp-2016-10-31-models.jar"),
              force = force)
     f <- RCurl::CFILE(fp, mode="wb")
@@ -131,7 +135,7 @@ download_core_nlp <- function(
   }
 
   if (type %in% c("de")) {
-    fp <- .check_file_exists(file.path(output_loc, coreFile,
+    fp <- check_file_exists(file.path(output_loc, coreFile,
              "/stanford-german-corenlp-2016-10-31-models.jar"),
              force = force)
     f <- RCurl::CFILE(fp, mode="wb")
@@ -142,7 +146,7 @@ download_core_nlp <- function(
   }
 
   if (type %in% c("es")) {
-    fp <- .check_file_exists(file.path(output_loc, coreFile,
+    fp <- check_file_exists(file.path(output_loc, coreFile,
              "/stanford-spanish-corenlp-2016-10-31-models.jar"),
              force = force)
     f <- RCurl::CFILE(fp, mode="wb")
@@ -155,7 +159,7 @@ download_core_nlp <- function(
   ret
 }
 
-.check_file_exists <- function(path, force = FALSE) {
+check_file_exists <- function(path, force = FALSE) {
   if (file.exists(path) & !force) {
     stop(sprintf("file already exists at: %s", path))
   } else if (file.exists(path) & force) {
@@ -165,3 +169,33 @@ download_core_nlp <- function(
   return(path)
 }
 
+#' Download model files needed for udpipe
+#'
+#' The cleanNLP package does not supply the model files required
+#' for using the udpipe backend. These files can be downloaded
+#' with this function. The models are saved, by default, in the
+#' location where the package is installed. They will be saved
+#' between R sessions. This function is called internally by
+#' \code{\link{cnlp_init_udpipe}} if a model is not available.
+#'
+#' @param model_name   string giving the model namel.
+#'                     Defaults to "english" if NULL.
+#' @param model_loc    where should be model be downloaded to. If
+#'                     set to NULL, will be downloaded in the location
+#'                     that the cleanNLP package is installed.
+#'
+#'@examples
+#'\dontrun{
+#'cnlp_download_core_nlp()
+#'cnlp_download_core_nlp(type="spanish")
+#'}
+#' @export
+cnlp_download_udpipe <- function(model_name = "english", model_loc = NULL) {
+  if (is.null(model_loc)) {
+    model_loc <- system.file("extdata", package="cleanNLP")
+  }
+
+  udpipe::udpipe_download_model(language = model_name,
+                                model_dir = model_loc)
+
+}
\ No newline at end of file
