@@ -4,10 +4,9 @@ import datetime
 import io
 import numpy as np
 
-class SpacyCleanNLP:
+class spacyCleanNLP:
     """ A class to call spacy and output normalized tables """
     output_dir = None
-    doc_id_offset = 0
     language = ""
     entity_flag = True
     vector_flag = False
@@ -22,9 +21,6 @@ class SpacyCleanNLP:
     def setLanguage(self, language):
         self.language = language
 
-    def setIdOffset(self, doc_id_offset):
-        self.doc_id_offset = doc_id_offset
-
     def setEntityFlag(self, entity_flag):
         self.entity_flag = entity_flag
 
@@ -34,7 +30,7 @@ class SpacyCleanNLP:
     def processFiles(self, input_files):
         tfile, dfile, efile, mfile, vfile = prepare_output(self.output_dir, self.entity_flag, self.vector_flag)
 
-        id = self.doc_id_offset
+        id = 1
         for this_file in input_files:
             with io.open(this_file, 'r', errors = 'replace') as ifile:
                 text = ifile.read().replace(u'\r\n', u' ').replace(u'\n', u' ')
@@ -71,17 +67,17 @@ class SpacyCleanNLP:
         for ent in doc.ents:
             sid = self.sent_index.get(ent.sent.start, -1)
             tid_start = ent.start - ent.sent.start + 1
-            # NOTE: spaCy point one beyond entity, so do not add 1 here to tid_end:
+            # NOTE: spacy point one beyond entity, so do not add 1 here to tid_end:
             tid_end = ent.end - ent.sent.start
             entity = ent.text.replace('"','')
-            orow = u'{:d},{:d},{:d},{:d},"{:s}","{:s}"\n'.format(id, sid + 1,
+            orow = u'doc{:d},{:d},{:d},{:d},"{:s}","{:s}"\n'.format(id, sid + 1,
                     tid_start, tid_end, ent.root.ent_type_, entity)
             _ = efile.write(orow)
 
 
 def save_doc_meta(mfile, id, language, fname):
     st = datetime.datetime.utcnow().strftime('%Y-%m-%d %H:%M:%SZ')
-    orow = u'{:d},"{:s}","{:s}","{:s}","{:s}"\n'.format(id, st, spacy.about.__version__, language, fname)
+    orow = u'doc{:d},"{:s}","{:s}","{:s}","{:s}"\n'.format(id, st, spacy.about.__version__, language, fname)
     _ = mfile.write(orow)
 
 
@@ -91,7 +87,7 @@ def save_doc_token(doc, tfile, id):
     for x in doc.sents:
         tid = 0
         # The 0th token is always the ROOT
-        orow = u'{:d},{:d},{:d},"ROOT","ROOT","","",\n'.format(id, sid + 1, tid)
+        orow = u'doc{:d},{:d},{:d},"ROOT","ROOT","","",\n'.format(id, sid + 1, tid)
         _ = tfile.write(orow)
 
         # Now, parse the actual tokens, starting at 1
@@ -115,7 +111,7 @@ def save_doc_token(doc, tfile, id):
             # if this_lemma == "'":
             #     this_lemma = '\\\''
 
-            orow = u'{:d},{:d},{:d},"{:s}","{:s}","{:s}","{:s}",{:d}\n'.format(id, sid + 1,
+            orow = u'doc{:d},{:d},{:d},"{:s}","{:s}","{:s}","{:s}",{:d}\n'.format(id, sid + 1,
                     tid, this_text, this_lemma, word.pos_, word.tag_, word.idx)
             _ = tfile.write(orow)
             tid += 1
@@ -127,7 +123,7 @@ def save_doc_dependency(doc, dfile, id):
     tid = 0
     for x in doc.sents:
         # spacy counts tokens over the whole doc, but we
-        # want it within a sentence as with coreNLP. So
+        # want it within a sentence as with corenlp. So
         # save the first at sentence start and substract
         # it off
         start_token_i = x[0].i
@@ -138,7 +134,7 @@ def save_doc_dependency(doc, dfile, id):
                 dep_id = 0
             else:
                 dep_id = word.head.i - start_token_i + 1
-            orow = u'{:d},{:d},{:d},{:d},"{:s}",""\n'.format(id, sid + 1,
+            orow = u'doc{:d},{:d},{:d},{:d},"{:s}",""\n'.format(id, sid + 1,
                 dep_id, tid, word.dep_)
             _ = dfile.write(orow)
             tid += 1
@@ -151,8 +147,6 @@ def save_doc_vector(doc, vfile, id):
     for x in doc.sents:
         tid = 1 # no vector for the ROOT
         for word in x:
-            orow = u'{:d},{:d},{:d},'.format(id, sid + 1, tid)
-            _ = vfile.write(orow)
             # TODO: How precise does this really need to be? 4 decimal
             #       places seems enough and saves room; is anything
             #       lost?
