@@ -22,7 +22,7 @@ public class CSVDocumentDocumentWriter {
   public String print(Annotation doc) {
 
     StringBuilder sb = new StringBuilder();
-    sb.append(String.format("%s,%s,%s,%s,\"%s\"%n", docID, this.starttime,
+    sb.append(String.format("doc%s,%s,%s,%s,\"%s\"%n", docID, this.starttime,
                             this.version, this.language, this.uri));
 
     return sb.toString();
